==> mars-0.1.1-src.tar.gz: mars-0.1.1/src/Functions.h <==
#ifndef FUNCTIONS
#define FUNCTIONS

#include <functional>
#include <string>

#include "graphic/AlphaImage.h"
#include "graphic/Image.h"
#include "graphic/Surface.h"
#include "graphic/Text.h"

#include "DataTypes.h"
#include "Element.h"
#include "Object.h"

//sin(-45) & cos(-45)
#define SIN_MIN_45 -0.707106
#define COS_MIN_45 0.707106

#define TAN_22_5 0.414213
#define TAN_67_5 2.414213

// temporary menu 
#define X_R1_OFFSET 20
#define X_R2_OFFSET 40
#define X_R1_COMM_OFFSET 65
#define X_R2_COMM_OFFSET 85
#define DIM_FONT_MENU 25
#define DIM_FONT_COMMANDS1 12
#define DIM_FONT_COMMANDS2 10
// 800x600
#define RIS1_W 800
#define RIS1_H 600
// 1024x768
#define RIS2_W 1024
#define RIS2_H 768

/// return screen coordinates from iso ones origin represents the origin of 
/// the isometric plane
FloatPoint * iso2scr(Point iso, Point origin);

/// return screen coordinates from iso ones origin represents the origin of 
/// the isometric plane
FloatPoint * iso2scr(Sint16 ix, Sint16 iy, Sint16 ox, Sint16 oy);

/// return true if 2 images have an overlapping Point, false otherwise
bool ImageCollide(graphic::Image & img1, graphic::Image & img2);

/// return true if 2 objects have an overlapping Point, false otherwise
bool ObjectCollide(Object * ob1, Object * ob2, graphic::Image * img1, graphic::Image * img2);

/// return the relative orientation of an origin cell respect another
int RelDirection(Point * origin, Point * direction);
/// return the relative orientation of an origin cell respect another
int RelDirection(Sint16 ox, Sint16 oy, Sint16 dx, Sint16 dy);

// temporary menu
void menu(Options & op);

#endif

==> mars-0.1.2-src.tar.gz: mars-0.1.2/src/Functions.h <==
#ifndef FUNCTIONS
#define FUNCTIONS

#include <functional>
#include <string>

#include "graphic/GLImage.h"
#include "graphic/GLSurface.h"
#include "graphic/GLText.h"
#include "graphic/SDLImage.h"
#include "graphic/SDLSurface.h"
#include "graphic/SDLText.h"

#include "DataTypes.h"
#include "Element.h"
#include "Object.h"

//sin(-45) & cos(-45)
#define SIN_MIN_45 -0.707106
#define COS_MIN_45 0.707106

#define TAN_22_5 0.414213
#define TAN_67_5 2.414213

// temporary menu
#define MENU_X_OFFSET 40
#define HELP_X_OFFSET 40
#define HELP_X_OFFSET2 50
#define DIM_FONT_MENU 25
#define DIM_FONT_HELP1 12
#define DIM_FONT_HELP2 10
// 800x600
#define RIS1_W 800
#define RIS1_H 600
// 1024x768
#define RIS2_W 1024
#define RIS2_H 768

/// return screen coordinates from iso ones origin represents the origin of
/// the isometric plane
FloatPoint * iso2scr(Point iso, Point origin);

/// return screen coordinates from iso ones origin represents the origin of
/// the isometric plane
FloatPoint * iso2scr(Sint16 ix, Sint16 iy, Sint16 ox, Sint16 oy);

/// return true if 2 images have an overlapping Point, false otherwise
bool ImageCollide(graphic::Image & img1, graphic::Image & img2);

/// return true if 2 objects have an overlapping Point, false otherwise
bool ObjectCollide(Object * ob1, Object * ob2, graphic::Image * img1, graphic::Image * img2);

/// return the relative orientation of an origin cell respect another
int RelDirection(Point * origin, Point * direction);
/// return the relative orientation of an origin cell respect another
int RelDirection(Sint16 ox, Sint16 oy, Sint16 dx, Sint16 dy);

// temporary menu
void menu(Options & op);

#endif
